%global name spampd
%global version 2.62
%global rpmrelease 1

# only >= EL7 have IO::Socket::IP
%{!?_disable_io_socket_ip: %global _disable_io_socket_ip 0}

# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

# do only reload on upgrade, not restart. EL7 (systemd 219) uses systemctl ..
# 'reload-or-try-restart', EL8 uses systemctl .. 'try-reload-or-restart' and
# EL9 uses systemctl set-property .. 'needs-restart'
%if %{_has_systemd} == 219
%global _systemctl_try_reload reload-or-try-restart
%else
%global _systemctl_try_reload try-reload-or-restart
%endif
# patching expandable rpm macros is a bit tricky
%global _systemd_postun_with_reload_service %(%{__cat} << "EOF" |
%systemd_postun_with_restart %{name}.service
EOF
  %{__perl} -pi -e "s|try-restart\ |%{_systemctl_try_reload} |g" |
  %{__perl} -pi -e "s|needs-restart\ |needs-reload |g")

Summary: Transparent SMTP/LMTP proxy filter using SpamAssassin
Name: %{name}
Version: %{version}
Release: %{rpmrelease}%{?dist}
License: GPL-3.0-or-later
Group: System Environment/Daemons
URL: http://www.worlddesign.com/index.cfm/page/software/open-source/spampd.htm
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: https://github.com/mpaperno/%{name}/archive/%{name}-%{version}.tar.gz
Source1: %{name}.%{_servicefile_postfix}
Source2: %{name}.sysconfig
%if %{_has_systemd}
Source3: %{name}-tmpfiles.conf
%endif
# patches => 100 should/will be fixed in SCM
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires: perl(Net::Server) >= 0.89
# not always required but recommended modules
Requires: perl(Data::Dumper)
Requires: perl(IO::Socket::UNIX)
%if %{_disable_io_socket_ip}
Requires: perl(IO::Socket::INET)
%else
Requires: perl(IO::Socket::IP)
%endif
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: %{__perl}

%description
SpamPD is an SMTP/LMTP proxy that marks (or tags) spam using
SpamAssassin (http://spamassassin.apache.org/). The proxy is designed
to be transparent to the sending and receiving mail servers and at no point
takes responsibility for the message itself. If a failure occurs within
SpamPD (or SpamAssassin) then the mail servers will disconnect and the
sending server is still responsible for retrying the message for as long
as it is configured to do so.

%prep
%setup -q

# apply SCM patches first, other patches my depend on them

# do all other patches
%if %{_disable_io_socket_ip}
%{__perl} -pi -e "s|::IP|::INET|g" %{name}.p*
%endif

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sbindir}
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_mandir}/man8
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}
%{__install} -d %{buildroot}%{_var}/spool/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -p -m 0755 %{name}.pl %{buildroot}%{_sbindir}/%{name}
%{__install} -p -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
pod2man --section=8 --center="%{summary}" %{name}.pl > %{buildroot}%{_mandir}/man8/%{name}.8

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name} 2> /dev/null || :
getent passwd %{name} > /dev/null || \
  %{_sbindir}/useradd -g %{name} -s /sbin/nologin -r -M -c "Spampd User" -d %{_var}/spool/%{name} %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%_systemd_postun_with_reload_service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} reload > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc changelog.txt LICENSE.txt readme.md misc/*.cfg
%{_sbindir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%{_mandir}/man8/%{name}.8*
%attr(0755,%{name},root) %dir %{_pidbasedir}/%{name}
%attr(0750,%{name},%{name}) %dir %{_var}/spool/%{name}

%changelog
* Mon Jan 13 2025 Simon Matter <simon.matter@invoca.ch> 2.62-1
- upgrade to 2.62

* Fri Jan 07 2022 Simon Matter <simon.matter@invoca.ch> 2.61-4
- add support for EL9

* Thu Aug 12 2021 Simon Matter <simon.matter@invoca.ch> 2.61-3
- update PR #37

* Wed Aug 11 2021 Simon Matter <simon.matter@invoca.ch> 2.61-2
- add patches from master
- add PR #37

* Sat Aug 07 2021 Simon Matter <simon.matter@invoca.ch> 2.61-1
- upgrade to 2.61

* Wed Aug 04 2021 Simon Matter <simon.matter@invoca.ch> 2.60-7
- add patch from master

* Wed Aug 04 2021 Simon Matter <simon.matter@invoca.ch> 2.60-6
- improve init script and systemd unit
- don't restart, only reload on RPM update

* Wed Aug 04 2021 Simon Matter <simon.matter@invoca.ch> 2.60-5
- add more patches

* Tue Aug 03 2021 Simon Matter <simon.matter@invoca.ch> 2.60-4
- add more patches

* Wed Jul 28 2021 Simon Matter <simon.matter@invoca.ch> 2.60-1
- upgrade to 2.60

* Wed Apr 22 2020 Simon Matter <simon.matter@invoca.ch> 2.53-2
- add support for EL8

* Mon Feb 25 2019 Simon Matter <simon.matter@invoca.ch> 2.53-1
- upgrade to 2.53

* Tue Nov 27 2018 Simon Matter <simon.matter@invoca.ch> 2.52-5
- improve init script
- improve default config

* Mon Nov 26 2018 Simon Matter <simon.matter@invoca.ch> 2.52-4
- improve systemd support

* Wed Nov 14 2018 Simon Matter <simon.matter@invoca.ch> 2.52-3
- move home from /var/cache/spampd to /var/spool/spampd

* Wed Nov 14 2018 Simon Matter <simon.matter@invoca.ch> 2.52-2
- move binary to /usr/sbin/
- add start_info patch

* Mon Nov 12 2018 Simon Matter <simon.matter@invoca.ch> 2.52-1
- upgrade to 2.52

* Tue Jun 12 2018 Simon Matter <simon.matter@invoca.ch> 2.51-1
- upgrade to 2.51

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 2.42-2
- small spec fixes for systemd

* Thu May 07 2015 Simon Matter <simon.matter@invoca.ch> 2.42-1
- upgrade to 2.42
- add support for systemd

* Wed Aug 10 2011 Simon Matter <simon.matter@invoca.ch> 2.30-8
- change defattr to fix directory permissions on EL6

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 2.30-7
- mass rebuild

* Fri Aug 06 2010 Simon Matter <simon.matter@invoca.ch> 2.30-6
- make init script wait for pidfile to vanish on shutting down spampd

* Fri Jan 29 2010 Simon Matter <simon.matter@invoca.ch> 2.30-5
- add spampd user

* Tue May 08 2007 Simon Matter <simon.matter@invoca.ch> 2.30-4
- add patch to fix memory/tmpfile leaks with SpamAssassin >= 3.2.0

* Mon May 08 2006 Simon Matter <simon.matter@invoca.ch> 2.30-3
- fix pre/post scripts in spec file

* Wed May 03 2006 Simon Matter <simon.matter@invoca.ch> 2.30-2
- fix perl modules dependencies

* Tue Nov 01 2005 Simon Matter <simon.matter@invoca.ch> 2.30-1
- update to version 2.30

* Tue Oct 04 2005 Simon Matter <simon.matter@invoca.ch> 2.20-5
- start spampd as user mail
- init script fixes
- use dedicated pid directory
- add small fixes from debian package

* Wed Feb 09 2005 Simon Matter <simon.matter@invoca.ch>
- added perl(Net::Server) as requirement
- added perl(Net::DNS) >= 0.34 as requirement

* Fri Dec 31 2004 Simon Matter <simon.matter@invoca.ch>
- updated the init script

* Sun Dec 19 2004 Simon Matter <simon.matter@invoca.ch>
- added missing Prereq
- updated to version 2.20 (only the version number has changed)
- use more macros in specfile

* Wed Oct 06 2004 Simon Matter <simon.matter@invoca.ch>
- updated to version 2.2

* Tue Oct 05 2004 Simon Matter <simon.matter@invoca.ch>
- added patch for SpamAssassin 3.0 compatibility

* Tue May 11 2004 Simon Matter <simon.matter@invoca.ch>
- initial build
